# Azure AI Resources Package client library for Python

This package has been deprecated and will no longer be maintained. It was heavily used in [Azure AI Generative](https://pypi.org/project/azure-ai-generative/) package which was already deprecated on 10-04-2024.

Please refer to new package [Azure AI Evaluation](https://pypi.org/project/azure-ai-evaluation/) for evaluating Generative AI applications that leverage Azure AI services.